==> portal-contribuinte-3.049.0.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/integracaocontabil/consulta-arrecadacao-por-lote.sql <==
select %s
       coalesce(sum((
         select sum(baixaautomatica.valorpago)
         from tribbaixaautomaticadetalhe baixaautomatica
         where lote.entidade = baixaautomatica.entidade
         and lote.exercicio = baixaautomatica.exercicio
         and lote.lote = baixaautomatica.lote
         and lote.arquivoretorno = 'S'
       )), 0) valorarquivo,

       coalesce(sum((
        select sum(coalesce(pagamentodebito.valorpago, 0) + coalesce(pagamentodebito.valorpagomaior, 0))
        from tribpagamento pagamento
        join tribpagamentobloqueto pagamentobloqueto on pagamento.entidade = pagamentobloqueto.entidade
                                      and pagamento.exerciciopagamento = pagamentobloqueto.exerciciopagamento
                                      and pagamento.pagamento = pagamentobloqueto.pagamento
        join tribpagamentodebito pagamentodebito on pagamentobloqueto.idpagamentobloqueto = pagamentodebito.idpagamentobloqueto
        where pagamento.entidade = lote.entidade
          and pagamento.exerciciolote = lote.exercicio
          and pagamento.lote = lote.lote
       )), 0) valorpagamento,

       coalesce(sum((
         select sum(coalesce(creditocontribuinteitem.valorlancado, 0))
         from tribbaixaautomaticadetalhe baixaautomatica
         join tribcreditocontribuinte creditocontribuinte on baixaautomatica.entidade = creditocontribuinte.entidade
                                                         and baixaautomatica.exerciciocredito = creditocontribuinte.exercicio
                                                         and baixaautomatica.creditocontribuinte = creditocontribuinte.creditocontribuinte
         join tribcreditocontribuinteitem creditocontribuinteitem on creditocontribuinte.entidade = creditocontribuinteitem.entidade
                                                                 and creditocontribuinte.exercicio = creditocontribuinteitem.exercicio
                                                                 and creditocontribuinte.creditocontribuinte = creditocontribuinteitem.creditocontribuinte
         where baixaautomatica.entidade = lote.entidade
           and baixaautomatica.exercicio = lote.exercicio
           and baixaautomatica.lote = lote.lote
       )), 0) valorcredito,

       coalesce(sum((
         select sum(pagamentodebito.valorpago)
         from tribpagamento pagamento
         join  tribestornopagamento estorno on pagamento.entidade = estorno.entidade
                                           and pagamento.exerciciopagamento = estorno.exerciciopagamento
                                           and pagamento.pagamento = estorno.pagamento
         join tribestornopagamentoitem estornopagamentoitem on estorno.entidade = estornopagamentoitem.entidade
                                                           and estorno.exercicio = estornopagamentoitem.exercicio
                                                           and estorno.estorno = estornopagamentoitem.estorno
         join contabancaria on estorno.entidade = contabancaria.entidade
                           and estorno.contabancariaestorno = contabancaria.contabancaria
         join tribpagamentodebito pagamentodebito on estornopagamentoitem.idpagamentobloqueto = pagamentodebito.idpagamentobloqueto
                                                 and estornopagamentoitem.iddebitoparcelareceita = pagamentodebito.iddebitoparcelareceita
         where pagamento.entidade = lote.entidade
           and pagamento.exerciciolote = lote.exercicio
           and pagamento.lote = lote.lote
           and estorno.data = lote.datamovimento
           and contabancaria.integraarrecadacao = 'S'
           and estorno.geracreditocontribuinte = 'N'
       )), 0) valorestornado,

       coalesce(sum((
         select sum(pagamentodebito.valorpago)
         from tribpagamento pagamento
         join tribestornopagamento estorno on pagamento.entidade = estorno.entidade
                                          and pagamento.exerciciopagamento = estorno.exerciciopagamento
                                          and pagamento.pagamento = estorno.pagamento
         join tribestornopagamentoitem estornopagamentoitem on estorno.entidade = estornopagamentoitem.entidade
                                                           and estorno.exercicio = estornopagamentoitem.exercicio
                                                           and estorno.estorno = estornopagamentoitem.estorno
         join contabancaria on estorno.entidade = contabancaria.entidade
                           and estorno.contabancariaestorno = contabancaria.contabancaria
         join tribpagamentodebito pagamentodebito on estornopagamentoitem.idpagamentobloqueto = pagamentodebito.idpagamentobloqueto
                                                 and estornopagamentoitem.iddebitoparcelareceita = pagamentodebito.iddebitoparcelareceita
         where pagamento.entidade = lote.entidade
           and pagamento.exerciciolote = lote.exercicio
           and pagamento.lote = lote.lote
           and estorno.DataReabilitacao = lote.datamovimento
           and estorno.reabilitado = 'S'
           and estorno.geracreditocontribuinte = 'N'
           and contabancaria.Integraarrecadacao = 'S'
       )), 0) valorreabilitado
from tribpagamentolote lote
join contabancaria on lote.entidade = contabancaria.entidade
                  and lote.contabancaria = contabancaria.contabancaria
join tribconvenio convenio on lote.entidade = convenio.entidade
                          and lote.convenio = convenio.convenio
where contabancaria.integraarrecadacao = 'S'
and lote.entidade = :entidade
and lote.datamovimento = :datamovimento
and (lote.arquivoretorno = 'S' or lote.lotemanual = 'S')
%s
%s
%s

==> portal-contribuinte-3.158.0.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/integracaocontabil/consulta-arrecadacao-por-lote.sql <==
select %s
       coalesce(sum((
         select sum(baixaautomatica.valorpago)
         from tribbaixaautomaticadetalhe baixaautomatica
         where lote.entidade = baixaautomatica.entidade
         and lote.exercicio = baixaautomatica.exercicio
         and lote.lote = baixaautomatica.lote
         and lote.arquivoretorno = 'S'
       )), 0) valorarquivo,
       coalesce(sum((
        select sum(coalesce(pagamentodebito.valorpago, 0) + coalesce(pagamentodebito.valorpagomaior, 0))
        from tribpagamento pagamento
        join tribpagamentobloqueto pagamentobloqueto on pagamento.entidade = pagamentobloqueto.entidade
                                      and pagamento.exerciciopagamento = pagamentobloqueto.exerciciopagamento
                                      and pagamento.pagamento = pagamentobloqueto.pagamento
        join tribpagamentodebito pagamentodebito on pagamentobloqueto.idpagamentobloqueto = pagamentodebito.idpagamentobloqueto
        where pagamento.entidade = lote.entidade
          and pagamento.exerciciolote = lote.exercicio
          and pagamento.lote = lote.lote
       )), 0) valorpagamento,
       coalesce(sum((
         select sum(coalesce(creditocontribuinteitem.valorlancado, 0))
         from tribbaixaautomaticadetalhe baixaautomatica
         join tribcreditocontribuinte creditocontribuinte on baixaautomatica.entidade = creditocontribuinte.entidade
                                                         and baixaautomatica.exerciciocredito = creditocontribuinte.exercicio
                                                         and baixaautomatica.creditocontribuinte = creditocontribuinte.creditocontribuinte
         join tribcreditocontribuinteitem creditocontribuinteitem on creditocontribuinte.entidade = creditocontribuinteitem.entidade
                                                                 and creditocontribuinte.exercicio = creditocontribuinteitem.exercicio
                                                                 and creditocontribuinte.creditocontribuinte = creditocontribuinteitem.creditocontribuinte
         where baixaautomatica.entidade = lote.entidade
           and baixaautomatica.exercicio = lote.exercicio
           and baixaautomatica.lote = lote.lote
       )), 0) valorcredito,
       coalesce(sum((
         select sum(pagamentodebito.valorpago)
         from tribpagamento pagamento
         join  tribestornopagamento estorno on pagamento.entidade = estorno.entidade
                                           and pagamento.exerciciopagamento = estorno.exerciciopagamento
                                           and pagamento.pagamento = estorno.pagamento
         join tribestornopagamentoitem estornopagamentoitem on estorno.entidade = estornopagamentoitem.entidade
                                                           and estorno.exercicio = estornopagamentoitem.exercicio
                                                           and estorno.estorno = estornopagamentoitem.estorno
         join contabancaria on estorno.entidade = contabancaria.entidade
                           and estorno.contabancariaestorno = contabancaria.contabancaria
         join tribpagamentodebito pagamentodebito on estornopagamentoitem.idpagamentobloqueto = pagamentodebito.idpagamentobloqueto
                                                 and estornopagamentoitem.iddebitoparcelareceita = pagamentodebito.iddebitoparcelareceita
         where pagamento.entidade = lote.entidade
           and pagamento.exerciciolote = lote.exercicio
           and pagamento.lote = lote.lote
           and estorno.data = lote.datamovimento
           and contabancaria.integraarrecadacao = 'S'
           and estorno.geracreditocontribuinte = 'N'
       )), 0) valorestornado,
       coalesce(sum((
         select sum(pagamentodebito.valorpago)
         from tribpagamento pagamento
         join tribestornopagamento estorno on pagamento.entidade = estorno.entidade
                                          and pagamento.exerciciopagamento = estorno.exerciciopagamento
                                          and pagamento.pagamento = estorno.pagamento
         join tribestornopagamentoitem estornopagamentoitem on estorno.entidade = estornopagamentoitem.entidade
                                                           and estorno.exercicio = estornopagamentoitem.exercicio
                                                           and estorno.estorno = estornopagamentoitem.estorno
         join contabancaria on estorno.entidade = contabancaria.entidade
                           and estorno.contabancariaestorno = contabancaria.contabancaria
         join tribpagamentodebito pagamentodebito on estornopagamentoitem.idpagamentobloqueto = pagamentodebito.idpagamentobloqueto
                                                 and estornopagamentoitem.iddebitoparcelareceita = pagamentodebito.iddebitoparcelareceita
         where pagamento.entidade = lote.entidade
           and pagamento.exerciciolote = lote.exercicio
           and pagamento.lote = lote.lote
           and estorno.DataReabilitacao = lote.datamovimento
           and estorno.reabilitado = 'S'
           and estorno.geracreditocontribuinte = 'N'
           and contabancaria.Integraarrecadacao = 'S'
       )), 0) valorreabilitado
from tribpagamentolote lote
join contabancaria on lote.entidade = contabancaria.entidade
                  and lote.contabancaria = contabancaria.contabancaria
join tribconvenio convenio on lote.entidade = convenio.entidade
                          and lote.convenio = convenio.convenio
where contabancaria.integraarrecadacao = 'S'
and lote.entidade = :entidade
and lote.datamovimento between :dataInicio and :dataFim
and (lote.arquivoretorno = 'S' or lote.lotemanual = 'S')
%s
%s
%s
